#include <avr/io.h>
#include <avr/interrupt.h>  /* for sei() */
#include <util/delay.h>     /* for _delay_ms() */
#include <avr/pgmspace.h>   /* required by usbdrv.h */

#include "peri.h"
#include "usbdrv.h"

#define RQ_GET_KEYPAD1       1
#define RQ_GET_KEYPAD2     	 2

/* ------------------------------------------------------------------------- */
/* ----------------------------- USB interface ----------------------------- */
/* ------------------------------------------------------------------------- */
usbMsgLen_t usbFunctionSetup(uint8_t data[8])
{
    usbRequest_t *rq = (void *)data;

    /* declared as static so they stay valid when usbFunctionSetup returns */
    static uint8_t switch_state1;
    static uint8_t switch_state2;
    
    if (rq->bRequest == RQ_GET_KEYPAD1)
    {
	uint8_t row = rq->wIndex.bytes[0];
	uint8_t col = rq->wValue.bytes[0];
	
	switch_state1 = getKeyMatrix1(row,col);
	//switch_state1 = ifKeyPressed1(row,col);

        /* point usbMsgPtr to the data to be returned to host */
        usbMsgPtr = &switch_state1;

        /* return the number of bytes of data to be returned to host */
        return 1;
    }
    
    if (rq->bRequest == RQ_GET_KEYPAD2)
    {
	uint8_t row = rq->wIndex.bytes[0];
	uint8_t col = rq->wValue.bytes[0];
	
	switch_state2 = getKeyMatrix2(row,col);

        /* point usbMsgPtr to the data to be returned to host */
        usbMsgPtr = &switch_state2;

        /* return the number of bytes of data to be returned to host */
        return 1;
    }

    /* default for not implemented requests: return no data back to host */
    return 0;
}

/* ------------------------------------------------------------------------- */
int main(void)
{
    init_keypad();
	
    usbInit();

    /* enforce re-enumeration, do this while interrupts are disabled! */
    usbDeviceDisconnect();
    _delay_ms(300);
    usbDeviceConnect();

    /* enable global interrupts */
    sei();

    /* main event loop */
    for(;;)
    {
        usbPoll();
    }

    return 0;
}

/* ------------------------------------------------------------------------- */
